#!/bin/bash
#----------
DATA=Differential
MyLAB='JAEA'
MyNUC='fe56 na23 pu239 u235 u238'
MyNUC1='fe56 na23'
#-----------------
mkdir plots
mkdir plots/${DATA}_relative
#==========================================
\rm -rf plots/${DATA}_relative/*
#
for LAB in ${MyLAB}
do
for NUC in ${MyNUC}
do
paste -d ' ' tmpfiles/${LAB}/nuclear_data_prior_${NUC}.txt tmpfiles/${LAB}/nuclear_data_post_${NUC}.txt >plots/nuclear_data.txt
#
cat >plots/input <<EOF
set terminal png font "/usr/share/fonts/truetype/liberation/LiberationSans-Regular.ttf" 11
set output 'plots/output.png'
set autoscale
set logscale x
set nologscale y
set xzeroaxis
set xrange[100:2E+07]
set xlabel "Energy [eV]"
set ylabel "Relative Variation/Uncertainty [no-dim]"
set label "${LAB} ${NUC}" at graph 0.04,0.95
set key center top
#
plot\
'plots/nuclear_data.txt' u 2:(\$29/\$7-1) title 'MF3/MT2 adjustment' with steps lt 1 lc 3 lw 2, \
'tmpfiles/${LAB}/nuclear_data_prior_${NUC}.txt'  u 2:8 title 'uncertainty (prior)'  with steps lt 3 lc 1, \
'tmpfiles/${LAB}/nuclear_data_post_${NUC}.txt'   u 2:8 title 'uncertainty (post)'   with steps lt 3 lc 2, \
'tmpfiles/${LAB}/nuclear_data_prior_${NUC}.txt'  u 2:(-\$8) notitle with steps lt 3 lc 1, \
'tmpfiles/${LAB}/nuclear_data_post_${NUC}.txt'   u 2:(-\$8) notitle with steps lt 3 lc 2
! mv plots/output.png plots/${DATA}_relative/${LAB}_${NUC}_MF3MT2.png
set output 'plots/output.png'
plot\
'plots/nuclear_data.txt' u 2:(\$31/\$9-1) title 'MF3/MT4 adjustment' with steps lt 1 lc 3 lw 2, \
'tmpfiles/${LAB}/nuclear_data_prior_${NUC}.txt'  u 2:10 title 'uncertainty (prior)'  with steps lt 3 lc 1, \
'tmpfiles/${LAB}/nuclear_data_post_${NUC}.txt'   u 2:10 title 'uncertainty (post)'   with steps lt 3 lc 2, \
'tmpfiles/${LAB}/nuclear_data_prior_${NUC}.txt'  u 2:(-\$10) notitle with steps lt 3 lc 1, \
'tmpfiles/${LAB}/nuclear_data_post_${NUC}.txt'   u 2:(-\$10) notitle with steps lt 3 lc 2
! mv plots/output.png plots/${DATA}_relative/${LAB}_${NUC}_MF3MT4.png
set output 'plots/output.png'
plot\
'plots/nuclear_data.txt' u 2:(\$33/\$11-1) title 'MF3/MT101 adjustment' with steps lt 1 lc 3 lw 2, \
'tmpfiles/${LAB}/nuclear_data_prior_${NUC}.txt'  u 2:12 title 'uncertainty (prior)'  with steps lt 3 lc 1, \
'tmpfiles/${LAB}/nuclear_data_post_${NUC}.txt'   u 2:12 title 'uncertainty (post)'   with steps lt 3 lc 2, \
'tmpfiles/${LAB}/nuclear_data_prior_${NUC}.txt'  u 2:(-\$12) notitle with steps lt 3 lc 1, \
'tmpfiles/${LAB}/nuclear_data_post_${NUC}.txt'   u 2:(-\$12) notitle with steps lt 3 lc 2
! mv plots/output.png plots/${DATA}_relative/${LAB}_${NUC}_MF3MT101.png
set output 'plots/output.png'
plot\
'plots/nuclear_data.txt' u 2:(\$35/\$13-1) title 'MF3/MT251 adjustment' with steps lt 1 lc 3 lw 2, \
'tmpfiles/${LAB}/nuclear_data_prior_${NUC}.txt'  u 2:14 title 'uncertainty (prior)'  with steps lt 3 lc 1, \
'tmpfiles/${LAB}/nuclear_data_post_${NUC}.txt'   u 2:14 title 'uncertainty (post)'   with steps lt 3 lc 2, \
'tmpfiles/${LAB}/nuclear_data_prior_${NUC}.txt'  u 2:(-\$14) notitle with steps lt 3 lc 1, \
'tmpfiles/${LAB}/nuclear_data_post_${NUC}.txt'   u 2:(-\$14) notitle with steps lt 3 lc 2
! mv plots/output.png plots/${DATA}_relative/${LAB}_${NUC}_MF3MT251.png
set output 'plots/output.png'
plot\
'plots/nuclear_data.txt' u 2:(\$37/\$15-1) title 'MF3/MT18 adjustment' with steps lt 1 lc 3 lw 2, \
'tmpfiles/${LAB}/nuclear_data_prior_${NUC}.txt'  u 2:16 title 'uncertainty (prior)'  with steps lt 3 lc 1, \
'tmpfiles/${LAB}/nuclear_data_post_${NUC}.txt'   u 2:16 title 'uncertainty (post)'   with steps lt 3 lc 2, \
'tmpfiles/${LAB}/nuclear_data_prior_${NUC}.txt'  u 2:(-\$16) notitle with steps lt 3 lc 1, \
'tmpfiles/${LAB}/nuclear_data_post_${NUC}.txt'   u 2:(-\$16) notitle with steps lt 3 lc 2
! mv plots/output.png plots/${DATA}_relative/${LAB}_${NUC}_MF3MT18.png
set output 'plots/output.png'
plot\
'plots/nuclear_data.txt' u 2:(\$39/\$17-1) title 'MF1/MT452 adjustment' with steps lt 1 lc 3 lw 2, \
'tmpfiles/${LAB}/nuclear_data_prior_${NUC}.txt'  u 2:18 title 'uncertainty (prior)'  with steps lt 3 lc 1, \
'tmpfiles/${LAB}/nuclear_data_post_${NUC}.txt'   u 2:18 title 'uncertainty (post)'   with steps lt 3 lc 2, \
'tmpfiles/${LAB}/nuclear_data_prior_${NUC}.txt'  u 2:(-\$18) notitle with steps lt 3 lc 1, \
'tmpfiles/${LAB}/nuclear_data_post_${NUC}.txt'   u 2:(-\$18) notitle with steps lt 3 lc 2
! mv plots/output.png plots/${DATA}_relative/${LAB}_${NUC}_MF1MT452.png
set output 'plots/output.png'
plot\
'plots/nuclear_data.txt' u 2:(\$41/\$19-1) title 'MF5/MT18 adjustment' with steps lt 1 lc 3 lw 2, \
'tmpfiles/${LAB}/nuclear_data_prior_${NUC}.txt'  u 2:20 title 'uncertainty (prior)'  with steps lt 3 lc 1, \
'tmpfiles/${LAB}/nuclear_data_post_${NUC}.txt'   u 2:20 title 'uncertainty (post)'   with steps lt 3 lc 2, \
'tmpfiles/${LAB}/nuclear_data_prior_${NUC}.txt'  u 2:(-\$20) notitle with steps lt 3 lc 1, \
'tmpfiles/${LAB}/nuclear_data_post_${NUC}.txt'   u 2:(-\$20) notitle with steps lt 3 lc 2
! mv plots/output.png plots/${DATA}_relative/${LAB}_${NUC}_MF5MT18.png
set output 'plots/output.png'
plot\
'plots/nuclear_data.txt' u 2:(\$43/\$21-1) title 'MF1/MT455 adjustment' with steps lt 1 lc 3 lw 2, \
'tmpfiles/${LAB}/nuclear_data_prior_${NUC}.txt'  u 2:22 title 'uncertainty (prior)'  with steps lt 3 lc 1, \
'tmpfiles/${LAB}/nuclear_data_post_${NUC}.txt'   u 2:22 title 'uncertainty (post)'   with steps lt 3 lc 2, \
'tmpfiles/${LAB}/nuclear_data_prior_${NUC}.txt'  u 2:(-\$22) notitle with steps lt 3 lc 1, \
'tmpfiles/${LAB}/nuclear_data_post_${NUC}.txt'   u 2:(-\$22) notitle with steps lt 3 lc 2
! mv plots/output.png plots/${DATA}_relative/${LAB}_${NUC}_MF1MT455.png
EOF
#
gnuplot plots/input
#
done
done
#
for LAB in ${MyLAB}
do
for NUC in ${MyNUC1}
do
\rm plots/${DATA}_relative/${LAB}_${NUC}_MF3MT18.png
\rm plots/${DATA}_relative/${LAB}_${NUC}_MF1MT452.png
\rm plots/${DATA}_relative/${LAB}_${NUC}_MF5MT18.png
\rm plots/${DATA}_relative/${LAB}_${NUC}_MF1MT455.png
done
done


#
exit
