#!/bin/bash
#-----------
DATA=Differential
MyREF1=INL
MyREF2=post
MyLAB='INL JAEA'
MyNUC='fe56 na23 pu239 u235 u238'
MyNUC1='fe56 na23'
#-------------------
mkdir plots
mkdir plots/${DATA}_rel_ref_${MyREF1}_${MyREF2}
#=======================================================
\rm -rf plots/${DATA}_rel_ref_${MyREF1}_${MyREF2}/*
#
for LAB in ${MyLAB}
do
for NUC in ${MyNUC}
do
paste -d ' ' tmpfiles/${MyREF1}/nuclear_data_${MyREF2}_${NUC}.txt tmpfiles/${LAB}/nuclear_data_post_${NUC}.txt >plots/nuclear_data_${MyREF2}.txt
paste -d ' ' tmpfiles/${MyREF1}/nuclear_data_prior_${NUC}.txt tmpfiles/${LAB}/nuclear_data_prior_${NUC}.txt >plots/nuclear_data_prior.txt
#
cat >plots/input <<EOF
set terminal png font "/usr/share/fonts/truetype/liberation/LiberationSans-Regular.ttf" 11
set output 'plots/output.png'
set autoscale
set logscale x
set nologscale y
set xzeroaxis
set xrange[100:2E+07]
set xlabel "Energy [eV]"
set ylabel "Relative Variation/Uncertainty [no-dim]"
set label "${LAB} ${NUC}" at graph 0.04,0.95
set key center top
#
plot\
'plots/nuclear_data_${MyREF2}.txt' u 2:(\$29/\$7-1) title 'MF3/MT2 post rel to ${MyREF1}${MyREF2}' with steps lt 1 lc 2 lw 2, \
'plots/nuclear_data_prior.txt' u 2:(\$29/\$7-1) title 'MF3/MT2 prior rel to ${MyREF1}prior' with steps lt 1 lc 1 lw 1, \
'tmpfiles/${LAB}/nuclear_data_prior_${NUC}.txt'  u 2:8 title 'prior uncertainty'  with steps lt 3 lc 0, \
'tmpfiles/${LAB}/nuclear_data_prior_${NUC}.txt'  u 2:(-\$8) notitle with steps lt 3 lc 0
! mv plots/output.png plots/${DATA}_rel_ref_${MyREF1}_${MyREF2}/${LAB}_${NUC}_MF3MT2_ref_${MyREF1}_${MyREF2}.png
set output 'plots/output.png'
plot\
'plots/nuclear_data_${MyREF2}.txt' u 2:(\$31/\$9-1) title 'MF3/MT4 post rel to ${MyREF1}${MyREF2}' with steps lt 1 lc 2 lw 2, \
'plots/nuclear_data_prior.txt' u 2:(\$31/\$9-1) title 'MF3/MT4 prior rel to ${MyREF1}prior' with steps lt 1 lc 1 lw 1, \
'tmpfiles/${LAB}/nuclear_data_prior_${NUC}.txt'  u 2:10 title 'prior uncertainty'  with steps lt 3 lc 0, \
'tmpfiles/${LAB}/nuclear_data_prior_${NUC}.txt'  u 2:(-\$10) notitle with steps lt 3 lc 0
! mv plots/output.png plots/${DATA}_rel_ref_${MyREF1}_${MyREF2}/${LAB}_${NUC}_MF3MT4_ref_${MyREF1}_${MyREF2}.png
set output 'plots/output.png'
plot\
'plots/nuclear_data_${MyREF2}.txt' u 2:(\$33/\$11-1) title 'MF3/MT101 post rel to ${MyREF1}${MyREF2}' with steps lt 1 lc 2 lw 2, \
'plots/nuclear_data_prior.txt' u 2:(\$33/\$11-1) title 'MF3/MT101 prior rel to ${MyREF1}prior' with steps lt 1 lc 1 lw 1, \
'tmpfiles/${LAB}/nuclear_data_prior_${NUC}.txt'  u 2:12 title 'prior uncertainty'  with steps lt 3 lc 0, \
'tmpfiles/${LAB}/nuclear_data_prior_${NUC}.txt'  u 2:(-\$12) notitle with steps lt 3 lc 0
! mv plots/output.png plots/${DATA}_rel_ref_${MyREF1}_${MyREF2}/${LAB}_${NUC}_MF3MT101_ref_${MyREF1}_${MyREF2}.png
set output 'plots/output.png'
plot\
'plots/nuclear_data_${MyREF2}.txt' u 2:(\$35/\$13-1) title 'MF3/MT251 post rel to ${MyREF1}${MyREF2}' with steps lt 1 lc 2 lw 2, \
'plots/nuclear_data_prior.txt' u 2:(\$35/\$13-1) title 'MF3/MT251 prior rel to ${MyREF1}prior' with steps lt 1 lc 1 lw 1, \
'tmpfiles/${LAB}/nuclear_data_prior_${NUC}.txt'  u 2:14 title 'prior uncertainty'  with steps lt 3 lc 0, \
'tmpfiles/${LAB}/nuclear_data_prior_${NUC}.txt'  u 2:(-\$14) notitle with steps lt 3 lc 0
! mv plots/output.png plots/${DATA}_rel_ref_${MyREF1}_${MyREF2}/${LAB}_${NUC}_MF3MT251_ref_${MyREF1}_${MyREF2}.png
set output 'plots/output.png'
plot\
'plots/nuclear_data_${MyREF2}.txt' u 2:(\$37/\$15-1) title 'MF3/MT18 post rel to ${MyREF1}${MyREF2}' with steps lt 1 lc 2 lw 2, \
'plots/nuclear_data_prior.txt' u 2:(\$37/\$15-1) title 'MF3/MT18 prior rel to ${MyREF1}prior' with steps lt 1 lc 1 lw 1, \
'tmpfiles/${LAB}/nuclear_data_prior_${NUC}.txt'  u 2:16 title 'prior uncertainty'  with steps lt 3 lc 0, \
'tmpfiles/${LAB}/nuclear_data_prior_${NUC}.txt'  u 2:(-\$16) notitle with steps lt 3 lc 0
! mv plots/output.png plots/${DATA}_rel_ref_${MyREF1}_${MyREF2}/${LAB}_${NUC}_MF3MT18_ref_${MyREF1}_${MyREF2}.png
set output 'plots/output.png'
plot\
'plots/nuclear_data_${MyREF2}.txt' u 2:(\$39/\$17-1) title 'MF1/MT452 post rel to ${MyREF1}${MyREF2}' with steps lt 1 lc 2 lw 2, \
'plots/nuclear_data_prior.txt' u 2:(\$39/\$17-1) title 'MF1/MT452 prior rel to ${MyREF1}prior' with steps lt 1 lc 1 lw 1, \
'tmpfiles/${LAB}/nuclear_data_prior_${NUC}.txt'  u 2:18 title 'prior uncertainty'  with steps lt 3 lc 0, \
'tmpfiles/${LAB}/nuclear_data_prior_${NUC}.txt'  u 2:(-\$18) notitle with steps lt 3 lc 0
! mv plots/output.png plots/${DATA}_rel_ref_${MyREF1}_${MyREF2}/${LAB}_${NUC}_MF1MT452_ref_${MyREF1}_${MyREF2}.png
set output 'plots/output.png'
plot\
'plots/nuclear_data_${MyREF2}.txt' u 2:(\$41/\$19-1) title 'MF5/MT18 post rel to ${MyREF1}${MyREF2}' with steps lt 1 lc 2 lw 2, \
'plots/nuclear_data_prior.txt' u 2:(\$41/\$19-1) title 'MF5/MT18 prior rel to ${MyREF1}prior' with steps lt 1 lc 1 lw 1, \
'tmpfiles/${LAB}/nuclear_data_prior_${NUC}.txt'  u 2:20 title 'prior uncertainty'  with steps lt 3 lc 0, \
'tmpfiles/${LAB}/nuclear_data_prior_${NUC}.txt'  u 2:(-\$20) notitle with steps lt 3 lc 0
! mv plots/output.png plots/${DATA}_rel_ref_${MyREF1}_${MyREF2}/${LAB}_${NUC}_MF5MT18_ref_${MyREF1}_${MyREF2}.png
set output 'plots/output.png'
plot\
'plots/nuclear_data_${MyREF2}.txt' u 2:(\$43/\$21-1) title 'MF1/MT455 post rel to ${MyREF1}${MyREF2}' with steps lt 1 lc 2 lw 2, \
'plots/nuclear_data_prior.txt' u 2:(\$43/\$21-1) title 'MF1/MT455 prior rel to ${MyREF1}prior' with steps lt 1 lc 1 lw 1, \
'tmpfiles/${LAB}/nuclear_data_prior_${NUC}.txt'  u 2:22 title 'prior uncertainty'  with steps lt 3 lc 0, \
'tmpfiles/${LAB}/nuclear_data_prior_${NUC}.txt'  u 2:(-\$22) notitle with steps lt 3 lc 0
! mv plots/output.png plots/${DATA}_rel_ref_${MyREF1}_${MyREF2}/${LAB}_${NUC}_MF1MT455_ref_${MyREF1}_${MyREF2}.png
EOF
#
gnuplot plots/input
#
done
done
#
for LAB in ${MyLAB}
do
for NUC in ${MyNUC1}
do
\rm plots/${DATA}_rel_ref_${MyREF1}_${MyREF2}/${LAB}_${NUC}_MF3MT18_ref_${MyREF1}_${MyREF2}.png
\rm plots/${DATA}_rel_ref_${MyREF1}_${MyREF2}/${LAB}_${NUC}_MF1MT452_ref_${MyREF1}_${MyREF2}.png
\rm plots/${DATA}_rel_ref_${MyREF1}_${MyREF2}/${LAB}_${NUC}_MF5MT18_ref_${MyREF1}_${MyREF2}.png
\rm plots/${DATA}_rel_ref_${MyREF1}_${MyREF2}/${LAB}_${NUC}_MF1MT455_ref_${MyREF1}_${MyREF2}.png
done
done


#
exit
